summaryrefslogtreecommitdiff
path: root/pdf-over/pdf-signer-interface/src/main/java/at/asit/pdfover/pdfsigner/SignaturePosition.java
diff options
context:
space:
mode:
Diffstat (limited to 'pdf-over/pdf-signer-interface/src/main/java/at/asit/pdfover/pdfsigner/SignaturePosition.java')
-rw-r--r--pdf-over/pdf-signer-interface/src/main/java/at/asit/pdfover/pdfsigner/SignaturePosition.java37
1 files changed, 27 insertions, 10 deletions
diff --git a/pdf-over/pdf-signer-interface/src/main/java/at/asit/pdfover/pdfsigner/SignaturePosition.java b/pdf-over/pdf-signer-interface/src/main/java/at/asit/pdfover/pdfsigner/SignaturePosition.java
index f6d2aa81..82f37deb 100644
--- a/pdf-over/pdf-signer-interface/src/main/java/at/asit/pdfover/pdfsigner/SignaturePosition.java
+++ b/pdf-over/pdf-signer-interface/src/main/java/at/asit/pdfover/pdfsigner/SignaturePosition.java
@@ -9,18 +9,20 @@ public class SignaturePosition {
/**
* The x value of the position
*/
- protected int x = 0;
+ protected float x = 0;
/**
* The y value of the position
*/
- protected int y = 0;
+ protected float y = 0;
/**
* The page value of the position
*/
protected int page = 1;
+ protected boolean auto = true;
+
/**
* Default constructor
*/
@@ -32,7 +34,7 @@ public class SignaturePosition {
* @param x The x value of the position
* @param y The y value of the position
*/
- public SignaturePosition(int x, int y) {
+ public SignaturePosition(float x, float y) {
this.x = x;
this.y = y;
}
@@ -43,7 +45,7 @@ public class SignaturePosition {
* @param y The y value of the position
* @param page The page value of the position
*/
- public SignaturePosition(int x, int y, int page) {
+ public SignaturePosition(float x, float y, int page) {
this.x = x;
this.y = y;
this.page = page;
@@ -53,15 +55,15 @@ public class SignaturePosition {
* Sets X value of position
* @param value the new x value
*/
- public void SetX(int value) {
+ public void SetX(float value) {
this.x = value;
}
/**
* Gets the X value of the position
* @return int the x value of the position
*/
- public int GetX() {
+ public float GetX() {
return this.x;
}
@@ -69,15 +71,15 @@ public class SignaturePosition {
* Sets Y value of position
* @param value the new y value
*/
- public void SetY(int value) {
+ public void SetY(float value) {
this.y = value;
}
/**
* Gets the Y value of the position
* @return int the y value of the position
*/
- public int GetY() {
+ public float GetY() {
return this.y;
}
@@ -97,4 +99,19 @@ public class SignaturePosition {
return this.page;
}
+ /**
+ * Sets Page value of position
+ * @param value the new page value
+ */
+ public void SetAuto(boolean value) {
+ this.auto = value;
+ }
+
+ /**
+ * Gets the Page value of the position
+ * @return int the page value of the position
+ */
+ public boolean GetAuto() {
+ return this.auto;
+ }
}
@@ -53,15 +55,15 @@ public class SignaturePosition {
/**
* Gets the X value of the position
- * @return int the x value of the position
+ * @return float the x value of the position
*/
@@ -69,15 +71,15 @@ public class SignaturePosition {
/**
* Gets the Y value of the position
- * @return int the y value of the position
+ * @return float the y value of the position
*/